"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useVibration = void 0;
var _react = require("react");
var _reactNative = require("react-native");
/**
 * A custom React hook for handling device vibration.
 *
 * @returns {object} An object containing functions for vibration control. { vibrate, cancelVibration }
 * @property {Function} vibrate - Function to trigger vibration with a specific pattern.
 * @property {Function} cancelVibration - Function to cancel the ongoing vibration.
 *
 * * @example
 * // Import the hook
 * import { useVibration } from './path-to-your-hook';
 *
 * // Use the hook in a component
 * const MyComponent = () => {
 *   const { vibrate, cancelVibration } = useVibration();
 *
 *   const onVibratePress = () => {
 *     // Vibrate for 500 milliseconds
 *     vibrate(500);
 *   };
 *
 *   return (
 *     <View>
 *       <TouchableOpacity onPress={onVibratePress}>
 *         <Text>Vibrate Now</Text>
 *       </TouchableOpacity>
 *       <TouchableOpacity onPress={cancelVibration}>
 *         <Text>Cancel Vibration</Text>
 *       </TouchableOpacity>
 *     </View>
 *   );
 * };
 */
const useVibration = () => {
  const vibrate = (0, _react.useCallback)(pattern => {
    _reactNative.Vibration.vibrate(pattern);
  }, []);
  const cancelVibration = (0, _react.useCallback)(() => {
    _reactNative.Vibration.cancel();
  }, []);
  return {
    vibrate,
    cancelVibration
  };
};
exports.useVibration = useVibration;
//# sourceMappingURL=useVibration.js.map